==> open-cluster-management-agent-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigListFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KlusterletAddonConfigListFluentImpl<A extends KlusterletAddonConfigListFluent<A>> extends BaseFluent<A> implements KlusterletAddonConfigListFluent<A>{
  public KlusterletAddonConfigListFluentImpl() {
  }
  public KlusterletAddonConfigListFluentImpl(KlusterletAddonConfigList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
  }
  private String apiVersion;
  private ArrayList<KlusterletAddonConfigBuilder> items = new ArrayList<KlusterletAddonConfigBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(Integer index,KlusterletAddonConfig item) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
  }
  public A setToItems(Integer index,KlusterletAddonConfig item) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);
    if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
    if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
     return (A)this;
  }
  public A addToItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<KlusterletAddonConfig> items) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items) {
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<KlusterletAddonConfig> items) {
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<KlusterletAddonConfigBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<KlusterletAddonConfigBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      KlusterletAddonConfigBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KlusterletAddonConfig> getItems() {
    return items != null ? build(items) : null;
  }
  public List<KlusterletAddonConfig> buildItems() {
    return items != null ? build(items) : null;
  }
  public KlusterletAddonConfig buildItem(Integer index) {
    return this.items.get(index).build();
  }
  public KlusterletAddonConfig buildFirstItem() {
    return this.items.get(0).build();
  }
  public KlusterletAddonConfig buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public KlusterletAddonConfig buildMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate) {
    for (KlusterletAddonConfigBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate) {
    for (KlusterletAddonConfigBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<KlusterletAddonConfig> items) {
    if (this.items != null) { _visitables.get("items").removeAll(this.items);}
    if (items != null) {this.items = new ArrayList(); for (KlusterletAddonConfig item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items) {
    if (this.items != null) {this.items.clear();}
    if (items != null) {for (KlusterletAddonConfig item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public KlusterletAddonConfigListFluent.ItemsNested<A> addNewItem() {
    return new KlusterletAddonConfigListFluentImpl.ItemsNestedImpl();
  }
  public KlusterletAddonConfigListFluent.ItemsNested<A> addNewItemLike(KlusterletAddonConfig item) {
    return new KlusterletAddonConfigListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public KlusterletAddonConfigListFluent.ItemsNested<A> setNewItemLike(Integer index,KlusterletAddonConfig item) {
    return new KlusterletAddonConfigListFluentImpl.ItemsNestedImpl(index, item);
  }
  public KlusterletAddonConfigListFluent.ItemsNested<A> editItem(Integer index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public KlusterletAddonConfigListFluent.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public KlusterletAddonConfigListFluent.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public KlusterletAddonConfigListFluent.ItemsNested<A> editMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KlusterletAddonConfigListFluentImpl that = (KlusterletAddonConfigListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (items != null ? !items.equals(that.items) :that.items != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends KlusterletAddonConfigFluentImpl<KlusterletAddonConfigListFluent.ItemsNested<N>> implements KlusterletAddonConfigListFluent.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(Integer index,KlusterletAddonConfig item) {
      this.index = index;
      this.builder = new KlusterletAddonConfigBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new KlusterletAddonConfigBuilder(this);
    }
    KlusterletAddonConfigBuilder builder;
    Integer index;
    public N and() {
      return (N) KlusterletAddonConfigListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-agent-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigListFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KlusterletAddonConfigListFluentImpl<A extends KlusterletAddonConfigListFluent<A>> extends BaseFluent<A> implements KlusterletAddonConfigListFluent<A>{
  public KlusterletAddonConfigListFluentImpl() {
  }
  public KlusterletAddonConfigListFluentImpl(KlusterletAddonConfigList instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
  }
  private String apiVersion;
  private ArrayList<KlusterletAddonConfigBuilder> items = new ArrayList<KlusterletAddonConfigBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(int index,KlusterletAddonConfig item) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  public A setToItems(int index,KlusterletAddonConfig item) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  public A addToItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<KlusterletAddonConfig> items) {
    if (this.items == null) {this.items = new ArrayList<KlusterletAddonConfigBuilder>();}
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items) {
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<KlusterletAddonConfig> items) {
    for (KlusterletAddonConfig item : items) {KlusterletAddonConfigBuilder builder = new KlusterletAddonConfigBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<KlusterletAddonConfigBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<KlusterletAddonConfigBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      KlusterletAddonConfigBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KlusterletAddonConfig> getItems() {
    return items != null ? build(items) : null;
  }
  public List<KlusterletAddonConfig> buildItems() {
    return items != null ? build(items) : null;
  }
  public KlusterletAddonConfig buildItem(int index) {
    return this.items.get(index).build();
  }
  public KlusterletAddonConfig buildFirstItem() {
    return this.items.get(0).build();
  }
  public KlusterletAddonConfig buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public KlusterletAddonConfig buildMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate) {
    for (KlusterletAddonConfigBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate) {
    for (KlusterletAddonConfigBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<KlusterletAddonConfig> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (KlusterletAddonConfig item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (KlusterletAddonConfig item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public KlusterletAddonConfigListFluentImpl.ItemsNested<A> addNewItem() {
    return new KlusterletAddonConfigListFluentImpl.ItemsNestedImpl();
  }
  public KlusterletAddonConfigListFluentImpl.ItemsNested<A> addNewItemLike(KlusterletAddonConfig item) {
    return new KlusterletAddonConfigListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public KlusterletAddonConfigListFluentImpl.ItemsNested<A> setNewItemLike(int index,KlusterletAddonConfig item) {
    return new KlusterletAddonConfigListFluentImpl.ItemsNestedImpl(index, item);
  }
  public KlusterletAddonConfigListFluentImpl.ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public KlusterletAddonConfigListFluentImpl.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public KlusterletAddonConfigListFluentImpl.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public KlusterletAddonConfigListFluentImpl.ItemsNested<A> editMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KlusterletAddonConfigListFluentImpl that = (KlusterletAddonConfigListFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(items, that.items)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends KlusterletAddonConfigFluentImpl<KlusterletAddonConfigListFluentImpl.ItemsNested<N>> implements KlusterletAddonConfigListFluentImpl.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(int index,KlusterletAddonConfig item) {
      this.index = index;
      this.builder = new KlusterletAddonConfigBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new KlusterletAddonConfigBuilder(this);
    }
    KlusterletAddonConfigBuilder builder;
    int index;
    public N and() {
      return (N) KlusterletAddonConfigListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}
